@@ -3,7 +3,6 @@ package IO::YAML;
 use strict;
 use warnings;
 
-use YAML qw();
 use IO::File;
 use Errno;
 use Fcntl qw(:seek);
@@ -11,11 +10,14 @@ use Symbol;
 
 use vars qw($VERSION $AUTOLOAD);
 
-$VERSION = '0.08';
+$VERSION = '0.09';
+
+my ($yaml_loader, $yaml_dumper);
 
 sub new {
     my ($cls, @args) = @_;
     my %args;
+    ($yaml_loader, $yaml_dumper) = find_yaml_code() if !defined $yaml_loader;
     if (UNIVERSAL::isa($args[0], 'GLOB')) {
         # IO::YAML->new($fh)
         # IO::YAML->new($fh, $mode, %opt_args)
@@ -146,7 +148,7 @@ sub print {
     my $self = shift;
     my $fh = $self->handle || $self->open || die "Can't open: $!";
     my @terminator = $self->auto_terminate ? ("...\n") : ();
-    print $fh (YAML::Dump($_), @terminator) or die $!
+    print $fh ($yaml_dumper->($_), @terminator) or die $!
         foreach @_;
     return 1;
 }
@@ -173,7 +175,7 @@ sub getline {
         }
         $source .= $line;
     }
-    my $retval = $self->auto_load ? YAML::Load($source) : $source;
+    my $retval = $self->auto_load ? $yaml_loader->($source) : $source;
     return $retval;
 }
 
@@ -181,7 +183,7 @@ sub getlines {
     my ($self) = @_;
     my $fh = $self->handle || $self->open || die "Can't open: $!";
     my @lines = <$fh>;
-    return YAML::Load(join('', @lines));
+    return $yaml_loader->(join('', @lines));
 }
 
 sub next {
@@ -446,6 +448,26 @@ sub fh_eof {
     }
 }
 
+sub find_yaml_code {
+    my @yaml_packages = qw(
+        YAML::Any
+        YAML::XS
+        YAML::Syck
+        YAML::Old
+        YAML
+        YAML::Tiny
+    );
+    for my $pkg (@yaml_packages) {
+        (my $path = $pkg) =~ s/::/\//g;
+        $path .= '.pm';
+        return $pkg if exists $INC{$path};
+        eval "require $pkg; 1" or next;
+        my $L = $pkg->can('Load') or next;
+        my $D = $pkg->can('Dump') or next;
+        return ($L, $D);
+    }
+    die "Couldn't find a suitable YAML package";
+}
 
 1;
 
